@@ -52,7 +52,7 @@ ge_factanal <- function(.data, env, gen, rep, resp, mineval = 1,
     factors  <-
         .data %>%
         select({{env}}, {{gen}}, {{rep}}) %>%
-        mutate_all(as.factor)
+        mutate(across(everything(), as.factor))
     vars <- .data %>% select({{resp}}, -names(factors))
     vars %<>% select_numeric_cols()
     factors %<>% set_names("ENV", "GEN", "REP")
