@@ -34,11 +34,11 @@
 #'   \strong{All effects, except the error, are assumed to be fixed.}
 #' @param mresp  The new maximum value after rescaling the response variable. By
 #'   default, all variables in \code{resp} are rescaled so that de maximum value
-#'   is 100 and the minimum value is 0 (i.e., \code{mresp = 100}). It must be a
-#'   numeric vector of the same length of \code{resp} if rescaling is assumed to
-#'   be different across variables, e.g., if for the first variable smaller
+#'   is 100 and the minimum value is 0 (i.e., \code{mresp = NULL}). It must be a
+#'   character vector of the same length of \code{resp} if rescaling is assumed
+#'   to be different across variables, e.g., if for the first variable smaller
 #'   values are better and for the second one, higher values are better, then
-#'   \code{mresp = c(0, 100)} must be used. Numeric value of length 1 will be
+#'   \code{mresp = c("l, h")} must be used. Character value of length 1 will be
 #'   recycled with a warning message.
 #' @param wresp The weight for the response variable(s) for computing the WAASBY
 #'   index. By default, all variables in \code{resp} have equal weights for mean
@@ -155,7 +155,7 @@
 #'                gen = GEN,
 #'                rep = REP,
 #'                resp = c(GY, HM),
-#'                mresp = c(100, 0),
+#'                mresp = c("h, l"),
 #'                wresp = c(60, 40))
 #'
 #'
@@ -175,6 +175,9 @@ waas <- function(.data,
                  naxis = NULL,
                  ind_anova = FALSE,
                  verbose = TRUE) {
+    if(is.numeric(mresp)){
+        stop("Using a numeric vector in 'mresp' is deprecated as of metan 1.9.0. use 'h' or 'l' instead.\nOld code: 'mresp = c(100, 100, 0)'.\nNew code: 'mresp = c(\"h, h, l\")", call. = FALSE)
+    }
     if(!missing(block)){
         factors  <- .data %>%
             select({{env}},
@@ -208,17 +211,24 @@ waas <- function(.data,
         mresp <- replicate(nvar, 100)
         minresp <- 100 - mresp
     } else {
-        mresp <- mresp
-        minresp <- 100 - mresp
+        mresp <- unlist(strsplit(mresp, split="\\s*(\\s|,)\\s*")) %>% all_lower_case()
+        if(!any(mresp %in% c("h", "l", "H", "L"))){
+            if(!mresp[[1]] %in% c("h", "l")){
+                stop("Argument 'mresp' must have only h or l.", call. = FALSE)
+            } else{
+                warning("Argument 'mresp' must have only h or l. Setting mresp = ", mresp[[1]],
+                        " to all the ", nvar, " variables.", call. = FALSE)
+                mresp <- replicate(nvar, mresp[[1]])
+            }
+        }
         if (length(mresp) != nvar) {
             warning("Invalid length in 'mresp'. Setting mresp = ", mresp[[1]],
                     " to all the ", nvar, " variables.", call. = FALSE)
             mresp <- replicate(nvar, mresp[[1]])
-            minresp <- 100 - mresp
-        }
-        if (sum(mresp == 100) + sum(mresp == 0) != nvar) {
-            stop("The values of the numeric vector 'mresp' must be 0 or 100.")
         }
+
+        mresp <- ifelse(mresp == "h", 100, 0)
+        minresp <- 100 - mresp
     }
     if (is.null(wresp)) {
         PesoResp <- replicate(nvar, 50)
